@@ -3,12 +3,12 @@
 use strict;
 use warnings;
 
-use lib '../lib';
+use lib qw(../lib  lib);
 use POE qw(Component::IRC  Component::IRC::Plugin::CSS::SelectorTools);
 
 my $irc = POE::Component::IRC->spawn(
     nick        => 'CSSToolsBot',
-    server      => '127.0.0.1',
+    server      => 'irc.freenode.net',
     port        => 6667,
     ircname     => 'CSSToolsBot',
     plugin_debug => 1,
